@@ -29,10 +29,10 @@ extern "C" {
 #define MagickCopyright  "© 1999-2018 ImageMagick Studio LLC"
 #define MagickLibVersion  0x707
 #define MagickLibVersionText  "7.0.7"
-#define MagickLibVersionNumber  5,0,0
-#define MagickLibAddendum  "-28"
-#define MagickLibInterface  5
-#define MagickLibMinInterface  5
+#define MagickLibVersionNumber  6,0,0
+#define MagickLibAddendum  "-35"
+#define MagickLibInterface  6
+#define MagickLibMinInterface  6
 #if defined(_WINDOWS)
 #  if defined(_WIN64)
 #    define MagickPlatform "x64"
@@ -44,13 +44,13 @@ extern "C" {
 #endif
 #define MagickppLibVersionText  "7.0.7"
 #define MagickppLibVersionNumber  4:0:0
-#define MagickppLibAddendum  "-28"
+#define MagickppLibAddendum  "-35"
 #define MagickppLibInterface  4
 #define MagickppLibMinInterface  4
-#define MagickReleaseDate  "2018-03-31"
+#define MagickReleaseDate  "2018-05-22"
 #define MagickAuthoritativeLicense  \
-  "http://www.imagemagick.org/script/license.php"
-#define MagickAuthoritativeURL  "http://www.imagemagick.org"
+  "https://www.imagemagick.org/script/license.php"
+#define MagickAuthoritativeURL  "https://www.imagemagick.org"
 #define MagickHomeURL  "file:///usr/share/doc/ImageMagick-7/index.html"
 #if (MAGICKCORE_QUANTUM_DEPTH == 8)
 #define MagickQuantumDepth  "Q8"
